@@ -1,9 +1,7 @@
-from .Client import Client
 from .Database import Database
 
-__version__ = '0.1.0'
+__version__ = '0.2.0'
 
 __all__ = [
-    "Client",
     "Database"
 ]
